"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InvalidParamsPassedToCommandError = exports.InclusionAlreadyInProgressError = exports.InclusionPhaseNotInProgressError = exports.EndpointNotFoundError = exports.VirtualEndpointNotFoundError = exports.SchemaIncompatibleError = exports.NodeNotFoundError = exports.UnknownCommandError = exports.UnknownError = exports.BaseError = exports.ErrorCode = void 0;
var ErrorCode;
(function (ErrorCode) {
    ErrorCode["unknownError"] = "unknown_error";
    ErrorCode["unknownCommand"] = "unknown_command";
    ErrorCode["nodeNotFound"] = "node_not_found";
    ErrorCode["endpointNotFound"] = "endpoint_not_found";
    ErrorCode["virtualEndpointNotFound"] = "virtual_endpoint_not_found";
    ErrorCode["schemaIncompatible"] = "schema_incompatible";
    ErrorCode["zwaveError"] = "zwave_error";
    ErrorCode["inclusionPhaseNotInProgress"] = "inclusion_phase_not_in_progress";
    ErrorCode["inclusionAlreadyInProgress"] = "inclusion_already_in_progress";
    ErrorCode["invalidParamsPassedToCommand"] = "invalid_params_passed_to_command";
})(ErrorCode || (exports.ErrorCode = ErrorCode = {}));
class BaseError extends Error {
}
exports.BaseError = BaseError;
class UnknownError extends BaseError {
    constructor(error) {
        super();
        this.error = error;
        this.errorCode = ErrorCode.unknownError;
    }
}
exports.UnknownError = UnknownError;
class UnknownCommandError extends BaseError {
    constructor(command) {
        super();
        this.command = command;
        this.errorCode = ErrorCode.unknownCommand;
    }
}
exports.UnknownCommandError = UnknownCommandError;
class NodeNotFoundError extends BaseError {
    constructor(nodeId) {
        super();
        this.nodeId = nodeId;
        this.errorCode = ErrorCode.nodeNotFound;
    }
}
exports.NodeNotFoundError = NodeNotFoundError;
class SchemaIncompatibleError extends BaseError {
    constructor(schemaId) {
        super();
        this.schemaId = schemaId;
        this.errorCode = ErrorCode.schemaIncompatible;
    }
}
exports.SchemaIncompatibleError = SchemaIncompatibleError;
class VirtualEndpointNotFoundError extends BaseError {
    constructor(index, nodeIDs, broadcast) {
        super();
        this.index = index;
        this.nodeIDs = nodeIDs;
        this.broadcast = broadcast;
        this.errorCode = ErrorCode.virtualEndpointNotFound;
    }
}
exports.VirtualEndpointNotFoundError = VirtualEndpointNotFoundError;
class EndpointNotFoundError extends BaseError {
    constructor(nodeId, index) {
        super();
        this.nodeId = nodeId;
        this.index = index;
        this.errorCode = ErrorCode.endpointNotFound;
    }
}
exports.EndpointNotFoundError = EndpointNotFoundError;
class InclusionPhaseNotInProgressError extends BaseError {
    constructor(phase) {
        super();
        this.phase = phase;
        this.errorCode = ErrorCode.inclusionPhaseNotInProgress;
    }
}
exports.InclusionPhaseNotInProgressError = InclusionPhaseNotInProgressError;
class InclusionAlreadyInProgressError extends BaseError {
    constructor() {
        super(...arguments);
        this.errorCode = ErrorCode.inclusionAlreadyInProgress;
    }
}
exports.InclusionAlreadyInProgressError = InclusionAlreadyInProgressError;
class InvalidParamsPassedToCommandError extends BaseError {
    constructor() {
        super(...arguments);
        this.errorCode = ErrorCode.invalidParamsPassedToCommand;
    }
}
exports.InvalidParamsPassedToCommandError = InvalidParamsPassedToCommandError;
